@@ -1,2 +1,4 @@
 /* ns_func.h	*/
 int munge_msg(int fd, size_t msglen, int is_tcp);
+char * errIP();
+u_int32_t * ns_response();
